==> open-cluster-management-cluster-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PrioritizerConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PrioritizerConfigFluent<A extends PrioritizerConfigFluent<A>> extends BaseFluent<A>{
  public PrioritizerConfigFluent() {
  }
  public PrioritizerConfigFluent(PrioritizerConfig instance) {
    instance = (instance != null ? instance : new PrioritizerConfig());

    if (instance != null) {
      this.withName(instance.getName());
      this.withWeight(instance.getWeight());
      this.withName(instance.getName());
      this.withWeight(instance.getWeight());
    }
  }
  private String name;
  private Integer weight;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public Integer getWeight() {
    return this.weight;
  }
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  public boolean hasWeight() {
    return this.weight != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrioritizerConfigFluent that = (PrioritizerConfigFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(weight, that.weight)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  weight,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-cluster-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/PrioritizerConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PrioritizerConfigFluent<A extends PrioritizerConfigFluent<A>> extends BaseFluent<A>{
  public PrioritizerConfigFluent() {
  }
  
  public PrioritizerConfigFluent(PrioritizerConfig instance) {
    this.copyInstance(instance);
  }
  private String name;
  private Integer weight;
  
  protected void copyInstance(PrioritizerConfig instance) {
    instance = (instance != null ? instance : new PrioritizerConfig());
  
    if (instance != null) {
        this.withName(instance.getName());
        this.withWeight(instance.getWeight());
        this.withName(instance.getName());
        this.withWeight(instance.getWeight());
      }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Integer getWeight() {
    return this.weight;
  }
  
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  
  public boolean hasWeight() {
    return this.weight != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrioritizerConfigFluent that = (PrioritizerConfigFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(weight, that.weight)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  weight,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  

}
